SystemOrganization addCategory: #ADayAtTheBeach!

Object subclass: #Calculator
	instanceVariableNames: 'operand1 operand2 operatorHit previousOperator display'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ADayAtTheBeach'!

!Calculator commentStamp: 'hs 11/6/2003 15:41' prior: 0!
I implement a simple calculator, with operations

	add
	subtract
	multiply
	divide


!

!Calculator class methodsFor: 'instance creation' stamp: 'svc 11/6/2003 14:05'!
new
	^super new initialize! !

!Calculator methodsFor: 'operations' stamp: 'svc 11/6/2003 14:23'!
clear
	self initialize! !

!Calculator methodsFor: 'operations' stamp: 'svc 11/6/2003 14:27'!
digit: digit
	operatorHit
		ifTrue: [display := digit asString]
		ifFalse: [display := display, digit asString].
	operatorHit := false.! !

!Calculator methodsFor: 'accessing' stamp: 'svc 11/6/2003 14:14'!
display
	^display! !

!Calculator methodsFor: 'operations' stamp: 'hs 11/6/2003 15:32'!
dot
	operatorHit
		ifTrue: [display := '0.']
		ifFalse: [
			(display includes: $.)
				ifFalse: [display := display, '.']].
	operatorHit := false.! !

!Calculator methodsFor: 'initialization' stamp: 'svc 11/6/2003 14:08'!
initialize

	operand1 := 0.
	operand2 := 0.
	previousOperator := #+.
	display := '0'.
	operatorHit := true.! !

!Calculator methodsFor: 'operations' stamp: 'SvenVanCaekenberghe 6/11/2010 18:15'!
operator: operation 
	[previousOperator = #=
		ifTrue: [operand1 := Number readFrom: display]
		ifFalse: [
			operand2 := Float readFrom: display.
			operand1 := operand1 perform: previousOperator with: operand2].
	previousOperator := operation.
	operatorHit := true.
	self updateDisplay] on: Error do: [self initialize. display := 'ERROR']! !

!Calculator methodsFor: 'private' stamp: 'svc 11/7/2003 11:38'!
updateDisplay
	(operand1 = operand1 asInteger)
		ifTrue: [display := operand1 asInteger asString]
		ifFalse: [display := operand1 printShowingDecimalPlaces: 3].
! !

TestCase subclass: #CalculatorTest
	instanceVariableNames: 'calculator'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ADayAtTheBeach'!

!CalculatorTest commentStamp: 'svc 11/8/2003 20:59' prior: 0!
I am the collection of unit tests for Calculator.!

!CalculatorTest methodsFor: 'testing' stamp: 'svc 11/6/2003 14:12'!
setUp
	calculator := Calculator new! !

!CalculatorTest methodsFor: 'testing' stamp: 'svc 11/6/2003 14:19'!
testChainedAddition
	calculator digit: 1; operator: #+; digit: 2; operator: #+; digit: 3; operator: #=.
	self assert: (calculator display = '6')
	! !

!CalculatorTest methodsFor: 'testing' stamp: 'svc 11/6/2003 19:46'!
testChainedCalculations
	calculator 
		digit: 1; digit: 0; operator: #+; digit: 2; digit: 0; 
		operator: #-; digit: 5; 
		operator: #/; digit: 5; 
		operator: #*; digit: 4; 
		operator: #=.
	self assert: (calculator display = '20')
	! !

!CalculatorTest methodsFor: 'testing' stamp: 'svc 11/7/2003 11:41'!
testDotAddition
	calculator digit: 1; dot; digit: 5; operator: #+; digit: 2; operator: #=.
	self assert: ((Float readFrom: calculator display) = 3.5)
	! !

!CalculatorTest methodsFor: 'testing' stamp: 'svc 11/6/2003 14:31'!
testDotAdditionOperatorHit
	calculator digit: 1; dot; digit: 5; operator: #+; dot; digit: 5; operator: #=.
	self assert: (calculator display = '2')
	! !

!CalculatorTest methodsFor: 'testing' stamp: 'svc 11/6/2003 19:47'!
testDotFirstAddition
	calculator dot; digit: 5; operator: #+; dot; digit: 5; operator: #=.
	self assert: (calculator display = '1')
	! !

!CalculatorTest methodsFor: 'testing' stamp: 'svc 11/6/2003 14:17'!
testSimpleAddition
	calculator digit: 1; operator: #+; digit: 2; operator: #=.
	self assert: (calculator display = '3')
	! !

!CalculatorTest methodsFor: 'testing' stamp: 'svc 11/7/2003 17:11'!
testStartSubtraction
	calculator operator: #-; digit: 6; operator: #=; operator: #*; digit: 3; operator: #=.
	self assert: (calculator display = '-18')! !

!CalculatorTest methodsFor: 'testing' stamp: 'svc 11/7/2003 17:09'!
testZeroDivide
	calculator digit: 1; operator: #/; digit: 0; operator: #=.
	self assert: (calculator display = 'ERROR')! !

WAComponent subclass: #DWBench
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ADayAtTheBeach'!

!DWBench commentStamp: 'svc 5/27/2010 21:14' prior: 0!
I am DWBench, a Seaside implementation of the DW-Bench dynamic web application benchmark.

See http://homepage.mac.com/svc/DW-Bench
!

!DWBench class methodsFor: 'testing' stamp: 'svc 5/27/2010 21:17'!
canBeRoot
	^true! !

!DWBench class methodsFor: 'class initialization' stamp: 'svc 5/27/2010 21:15'!
initialize
	WAAdmin register: self asApplicationAt: 'DW-Bench'! !

!DWBench methodsFor: 'rendering' stamp: 'svc 5/26/2010 12:16'!
renderContentOn: html

	html heading: 'DW-Bench Dynamic'.
	html table
		attributeAt: #border put: 1;
		with: [
			1 to: 25 do: [ :row | 
				html tableRow: [
					1 to: 25 do: [ :col | 
						html tableData: row * col ] ] ] ].
	html paragraph: TimeStamp now printString! !

WAComponent subclass: #WACalculator
	instanceVariableNames: 'calculator'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ADayAtTheBeach'!

!WACalculator commentStamp: '<historical>' prior: 0!
I am a web user interface to a simple calculator.
I am a standard Seaside web application.!

WACalculator subclass: #WAAjaxCalculator
	instanceVariableNames: 'displayId'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ADayAtTheBeach'!

!WAAjaxCalculator commentStamp: '<historical>' prior: 0!
I am a web user interface to a simple calculator.
I am an AJAX Seaside web application.!

!WAAjaxCalculator class methodsFor: 'class initialization' stamp: 'svc 6/7/2010 10:51'!
initialize
	(WAAdmin register: self asApplicationAt: 'calculator-ajax')
		preferenceAt: #sessionClass put: WAExpirySession;
		addLibrary: JQGoogleLibrary;
		addLibrary: JQUiGoogleLibrary! !

!WAAjaxCalculator methodsFor: 'rendering' stamp: 'svc 6/7/2010 11:07'!
renderButton: label callback: callback on: html
	(html div class: #key)
		onClick: ((html jQuery id: displayId) load html: [ :h |
			callback value. 
			h render: calculator display ]);
		onClick: ((html jQuery id: displayId) effect highlight color: 'green');
		onClick: ((html jQuery this) effect highlight color: 'white');
		with: label! !

!WAAjaxCalculator methodsFor: 'rendering' stamp: 'svc 6/6/2010 19:56'!
renderByLineOn: html
	html paragraph: 'Note how the full page does not reload when you click the buttons'! !

!WAAjaxCalculator methodsFor: 'rendering' stamp: 'svc 6/6/2010 19:58'!
renderHeadingOn: html
	displayId := html nextId.
	html heading id: displayId; with: calculator display! !

!WAAjaxCalculator methodsFor: 'rendering' stamp: 'svc 6/7/2010 10:44'!
style
^'
div#calculator {
	font-size: 30px;
	font-weight: bold;
	font-family: Helvetica, sansserif;
	padding: 5px;
	background:  #ccc;
	width: 253px;
	height: 320px;
	margin: 10px 10px 10px 10px;
}
div#calculator h1 {
	font-size: 30px;
	font-family: Monaco, mono-spaced;
	line-height: 1.2em;
	border: 2px solid black;
	padding: 5px 5px 5px 5px;
	margin: 2px 2px 2px;
	text-align: right;
	background: black;
	color: green;
}
div#calculator .row div.key {
	text-decoration: none; 
	text-align: center;
	border: 2px solid black;
	padding: 5px 10px 5px 10px;
	margin: 2px 2px 2px;
	background: #999;
	color: white;
	width: 35px; 
	float: left;
}
div#calculator #numpad {
	float: left;
	width: 190px;
}
div#calculator .row {
	clear: left;
}
div#calculator #operations {
	float: left;
}
'! !

!WACalculator class methodsFor: 'testing' stamp: 'svc 5/26/2010 10:46'!
canBeRoot
	^true! !

!WACalculator class methodsFor: 'class initialization' stamp: 'svc 5/27/2010 21:16'!
initialize
	WAAdmin register: self asApplicationAt: 'calculator'! !

!WACalculator methodsFor: 'initialization' stamp: 'svc 5/26/2010 10:47'!
initialize
	super initialize.
	calculator := Calculator new
! !

!WACalculator methodsFor: 'rendering' stamp: 'svc 6/5/2010 09:35'!
renderButton: label callback: callback on: html
	html anchor callback: callback; with: label! !

!WACalculator methodsFor: 'rendering' stamp: 'svc 6/6/2010 19:57'!
renderByLineOn: html
	html paragraph: 'If you make a mistake, you can use your browser''s back button to undo your last action(s)'! !

!WACalculator methodsFor: 'rendering' stamp: 'svc 6/6/2010 19:57'!
renderContentOn: html
	html div id: #calculator; with: [
		self renderHeadingOn: html.
		self renderNumpadOn: html.
		self renderOperationsOn: html ].
	self renderByLineOn: html! !

!WACalculator methodsFor: 'rendering' stamp: 'svc 6/6/2010 19:58'!
renderHeadingOn: html
	html heading: calculator display! !

!WACalculator methodsFor: 'rendering' stamp: 'svc 6/5/2010 09:38'!
renderNumpadOn: html
	html div id: #numpad; with: [
		#(#(7 8 9) #(4 5 6) #(1 2 3)) do: [ :eachRow |
			html div class: #row; with: [
			 	eachRow do: [ :each | 
					self renderButton: each callback: [ calculator digit: each ] on: html ] ] ].
		html div class: #row; with: [
			self renderButton: '0' callback: [ calculator digit: 0 ] on: html.
			self renderButton: '.' callback: [ calculator dot ] on: html.
			self renderButton: '=' callback: [ calculator operator: #= ] on: html ] ]! !

!WACalculator methodsFor: 'rendering' stamp: 'svc 6/5/2010 09:39'!
renderOperationsOn: html
	html div id: #operations; with: [
		#(#+ #- #* #/) do: [ :each | 
			html div class: #row; with: [
				self renderButton: each callback: [ calculator operator: each ] on: html ] ].
		html div class: #row; with: [
			self renderButton: 'C' callback: [ calculator clear ] on: html ] ]! !

!WACalculator methodsFor: 'hooks' stamp: 'svc 5/26/2010 11:39'!
states
	^ Array with: calculator! !

!WACalculator methodsFor: 'rendering' stamp: 'svc 5/27/2010 21:22'!
style
^'
div#calculator {
	font-size: 30px;
	font-weight: bold;
	font-family: Helvetica, sansserif;
	padding: 5px;
	background:  #ccc;
	width: 253px;
	height: 320px;
	margin: 10px 10px 10px 10px;
}
div#calculator h1 {
	font-size: 30px;
	font-family: Monaco, mono-spaced;
	line-height: 1.2em;
	border: 2px solid black;
	padding: 5px 5px 5px 5px;
	margin: 2px 2px 2px;
	text-align: right;
	background: black;
	color: green;
}
div#calculator a:link, div#calculator a:visited, div#calculator a:active, div#calculator a:hover {
	text-decoration: none; 
	text-align: center;
	border: 2px solid black;
	padding: 5px 10px 5px 10px;
	margin: 2px 2px 2px;
	background: #999;
	color: white;
}
div#calculator a:hover {
	background: black;
	color: white;
}
div#calculator a:active {
	background: black;
	color: white;
}
div#calculator div#numpad {
	float: left;
	width: 190px;
}
div#calculator .row a {
	width: 35px; 
	display: block;
	float: left;
}
div#calculator .row {
	clear: left;
}
div#calculator #operations {
	float: left;
}
'! !

WAComponent subclass: #WAFactorial
	instanceVariableNames: 'number'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ADayAtTheBeach'!

!WAFactorial commentStamp: 'svc 11/8/2003 21:00' prior: 0!
I am a web user interface to compute the factorial of a number.!

!WAFactorial class methodsFor: 'testing' stamp: 'svc 5/26/2010 11:07'!
canBeRoot
	^true! !

!WAFactorial class methodsFor: 'class initialization' stamp: 'svc 5/27/2010 21:16'!
initialize
	WAAdmin register: self asApplicationAt: 'factorial'! !

!WAFactorial methodsFor: 'initialization' stamp: 'svc 5/26/2010 10:08'!
initialize
	super initialize.
	number := 1.! !

!WAFactorial methodsFor: 'accessing' stamp: 'svc 11/6/2003 11:09'!
number
	^number! !

!WAFactorial methodsFor: 'accessing' stamp: 'svc 11/6/2003 11:09'!
number: anObject
	number := anObject! !

!WAFactorial methodsFor: 'rendering' stamp: 'svc 6/5/2010 20:48'!
renderContentOn: html
	html heading: 'Factorial Computation'.
	html form: [
		html textInput on: #number of: self.
		html space.
		html submitButton
			callback: [ self inform: self number, ' !! = ', self number asInteger factorial asString ];
			with: ' !! ' ]! !
DWBench initialize!
WAAjaxCalculator initialize!
WACalculator initialize!
WAFactorial initialize!
